'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var React = require('react');
var ReactDOM = require('react-dom');
var PropTypes = React.PropTypes;

var shouldPureComponentUpdate = require('react-pure-render/function');
var makePure = require('recompose/pure').default;
var DateIcon = require('material-ui/svg-icons/action/date-range').default;

var _require = require('material-ui/List'),
    ListItem = _require.ListItem;

var IconButton = require('material-ui/IconButton').default;
var EditIcon = require('material-ui/svg-icons/editor/mode-edit').default;

var _require2 = require('material-ui/Popover'),
    Popover = _require2.Popover,
    PopoverAnimationVertical = _require2.PopoverAnimationVertical;

var DateRange = makePure(require('react-date-range').DateRange);
var moment = require('moment');
var omit = require('lodash/omit');

var ShowAllButton = require('./show_all_button');

var _require3 = require('../util/text_helpers'),
    titleCase = _require3.titleCase;

var _require4 = require('../styles'),
    listStyles = _require4.listStyles;

var _require5 = require('../../config.json'),
    dateFormatShort = _require5.dateFormatShort;

var styles = {
  nestedList: {
    paddingTop: 0,
    paddingBottom: 0
  },
  dateItem: {
    marginLeft: 0,
    padding: '16px 56px 16px 16px',
    position: 'relative',
    fontSize: 14,
    lineHeight: '14px',
    color: 'rgba(0, 0, 0, 0.870588)'
  },
  iconButton: {
    padding: 12,
    width: 46,
    height: 46,
    top: 0,
    right: 4,
    background: 'none',
    position: 'absolute'
  },
  editIcon: {
    width: 20,
    height: 20
  },
  showAll: {
    fontSize: 12,
    lineHeight: '16px',
    height: 16,
    margin: '4px 0px 0px',
    overflow: 'hidden',
    textOverflow: 'ellipsis',
    whiteSpace: 'nowrap'
  }
};

// Material-ui passes a `nestedLevel` prop to nested items.
// We're not using a `div` instead of the material-ui component for
// nested items, so we need to remove the `nestedLevel` prop.
var NestedItem = function NestedItem(props) {
  var divProps = omit(props, ['nestedLevel', 'children']);
  return React.createElement(
    'div',
    divProps,
    props.children
  );
};

var DateFilter = function (_React$Component) {
  _inherits(DateFilter, _React$Component);

  function DateFilter() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, DateFilter);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = DateFilter.__proto__ || Object.getPrototypeOf(DateFilter)).call.apply(_ref, [this].concat(args))), _this), _this.state = {}, _this.shouldComponentUpdate = shouldPureComponentUpdate, _this.showDatePopover = function (event) {
      // This prevents ghost click.
      var target = _this.refs.dateRange;
      event.preventDefault();
      var range = document.createRange();
      var sel = window.getSelection();
      range.selectNodeContents(target);
      sel.removeAllRanges();
      sel.addRange(range);
      _this.setState({
        open: true,
        anchorEl: target
      });
    }, _this.handleNestedListToggle = function (e) {
      _this.setState({
        expanded: !_this.state.expanded
      });
    }, _this.showAllDates = function (e) {
      e.preventDefault();
      _this.handleDateChange({
        startDate: _this.props.valueMin,
        endDate: _this.props.valueMax
      });
    }, _this.handleDateChange = function (e) {
      if (e.startDate !== _this.props.startDate) {
        _this.props.onUpdate({
          exp: '>=',
          key: _this.props.fieldName,
          val: +e.startDate
        });
      }
      if (e.endDate !== _this.props.endDate) {
        _this.props.onUpdate({
          exp: '<=',
          key: _this.props.fieldName,
          val: +e.endDate
        });
      }
    }, _this.handleRequestClose = function () {
      _this.setState({
        open: false
      });
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(DateFilter, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.setState({
        el: ReactDOM.findDOMNode(this.refs.dateItem)
      });
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          fieldName = _props.fieldName,
          min = _props.min,
          max = _props.max,
          valueMin = _props.valueMin,
          valueMax = _props.valueMax;

      var isFiltered = min > valueMin || max < valueMax;
      var minMoment = moment(min);
      var maxMoment = moment(max);
      var rangeStr = minMoment.format(dateFormatShort) + ' — ' + maxMoment.format(dateFormatShort);
      return React.createElement(ListItem, {
        innerDivStyle: listStyles.listItemInner,
        primaryText: titleCase(fieldName),
        leftIcon: React.createElement(DateIcon, { style: listStyles.listIcon }),
        initiallyOpen: true,
        rightIconButton: isFiltered ? React.createElement(ShowAllButton, { onClick: this.showAllDates }) : null,
        disabled: true,
        ref: 'dateItem',
        nestedItems: [React.createElement(
          NestedItem,
          { style: styles.dateItem, key: 'dateItem' },
          React.createElement(
            'div',
            { ref: 'dateRange', onClick: this.showDatePopover },
            rangeStr
          ),
          React.createElement(
            IconButton,
            {
              onClick: this.showDatePopover,
              tooltip: 'Select dates',
              style: styles.iconButton,
              iconStyle: styles.editIcon,
              tooltipPosition: 'bottom-left' },
            React.createElement(EditIcon, { color: '#757575' })
          ),
          React.createElement(
            Popover,
            {
              open: this.state.open,
              anchorEl: this.state.el,
              anchorOrigin: { horizontal: 'left', vertical: 'bottom' },
              targetOrigin: { horizontal: 'left', vertical: 'top' },
              onRequestClose: this.handleRequestClose,
              animation: PopoverAnimationVertical
            },
            React.createElement(DateRange, {
              startDate: minMoment,
              endDate: maxMoment,
              onChange: this.handleDateChange })
          )
        )]
      });
    }
  }]);

  return DateFilter;
}(React.Component);

DateFilter.propTypes = {
  fieldName: PropTypes.string.isRequired,
  onUpdate: PropTypes.func
};


module.exports = DateFilter;