'use strict';

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var React = require('react');

var _require = require('react-redux'),
    connect = _require.connect;

var PropTypes = React.PropTypes;

var _require2 = require('material-ui/Card'),
    Card = _require2.Card,
    CardText = _require2.CardText,
    CardHeader = _require2.CardHeader;

var IconButton = require('material-ui/IconButton').default;
var CloseIcon = require('material-ui/svg-icons/navigation/close').default;

var _require3 = require('material-ui/List'),
    List = _require3.List,
    ListItem = _require3.ListItem;

var Toggle = require('material-ui/Toggle').default;

var _require4 = require('react-intl'),
    defineMessages = _require4.defineMessages,
    FormattedMessage = _require4.FormattedMessage;

var getFilterableFields = require('../selectors/filterable_fields');
var getVisibleFilters = require('../selectors/visible_filters');

var _require5 = require('../action_creators'),
    updateVisibleFilters = _require5.updateVisibleFilters;

var msg = require('../util/intl_helpers').createMessage;

var styles = {
  card: {
    width: '100%',
    flex: 1,
    display: 'flex',
    flexDirection: 'column'
  },
  cardContainerStyle: {
    flex: 1,
    flexDirection: 'column',
    display: 'flex'
  },
  header: {
    lineHeight: '22px',
    boxSizing: 'content-box',
    borderBottom: '1px solid #cccccc'
  },
  icon: {
    float: 'right'
  }
};

var messages = defineMessages({
  configureFilters: {
    id: 'filter.configure',
    defaultMessage: 'Configure Filters',
    description: 'Dialog title text when displaying available filters'
  }
});

var FilterConfigurator = function (_React$Component) {
  _inherits(FilterConfigurator, _React$Component);

  function FilterConfigurator() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, FilterConfigurator);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = FilterConfigurator.__proto__ || Object.getPrototypeOf(FilterConfigurator)).call.apply(_ref, [this].concat(args))), _this), _this.onToggle = function (fieldName) {
      var _this$props = _this.props,
          onUpdateVisibleFilters = _this$props.onUpdateVisibleFilters,
          visibleFilters = _this$props.visibleFilters;

      return function (_ref2) {
        var target = _ref2.target;

        var newVisibleFilters = void 0;

        if (target.checked) {
          newVisibleFilters = [].concat(_toConsumableArray(visibleFilters), [fieldName]);
        } else {
          var index = visibleFilters.indexOf(fieldName);
          newVisibleFilters = [].concat(_toConsumableArray(visibleFilters.slice(0, index)), _toConsumableArray(visibleFilters.slice(index + 1)));
        }

        onUpdateVisibleFilters(newVisibleFilters);
      };
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  _createClass(FilterConfigurator, [{
    key: 'render',
    value: function render() {
      var _this2 = this;

      var _props = this.props,
          filterableFields = _props.filterableFields,
          onCloseClick = _props.onCloseClick,
          visibleFilters = _props.visibleFilters;


      return React.createElement(
        Card,
        {
          style: styles.card,
          containerStyle: styles.cardContainerStyle,
          zDepth: 2 },
        React.createElement(
          CardHeader,
          {
            style: styles.header,
            title: React.createElement(
              'h3',
              { style: styles.title },
              React.createElement(FormattedMessage, messages.configureFilters)
            ) },
          React.createElement(
            IconButton,
            { style: styles.icon, onClick: onCloseClick },
            React.createElement(CloseIcon, null)
          )
        ),
        React.createElement(
          CardText,
          null,
          React.createElement(
            List,
            null,
            filterableFields.map(function (field) {
              return React.createElement(ListItem, {
                key: field,
                primaryText: React.createElement(FormattedMessage, msg('field_key')(field)),
                rightToggle: React.createElement(Toggle, {
                  toggled: visibleFilters.includes(field),
                  onToggle: _this2.onToggle(field)
                })
              });
            })
          )
        )
      );
    }
  }]);

  return FilterConfigurator;
}(React.Component);

FilterConfigurator.propTypes = {
  filterableFields: PropTypes.array.isRequired,
  onCloseClick: PropTypes.func.isRequired,
  onUpdateVisibleFilters: PropTypes.func.isRequired,
  visibleFilters: PropTypes.array.isRequired
};


function mapStateToProps(state) {
  return {
    filterableFields: getFilterableFields(state),
    visibleFilters: getVisibleFilters(state)
  };
}

function mapDispatchToProps(dispatch) {
  return {
    onUpdateVisibleFilters: function onUpdateVisibleFilters(filters) {
      return dispatch(updateVisibleFilters(filters));
    }
  };
}

module.exports = connect(mapStateToProps, mapDispatchToProps)(FilterConfigurator);