'use strict';

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var _require = require('reselect'),
    createSelector = _require.createSelector;

var _require2 = require('../constants'),
    FIELD_TYPES = _require2.FIELD_TYPES;

var getFieldAnalysis = require('./field_analysis');

function isArrayLike(fieldType) {
  return [FIELD_TYPES.ARRAY, FIELD_TYPES.NUMBER_OR_ARRAY, FIELD_TYPES.STRING_OR_ARRAY].indexOf(fieldType) > -1;
}

/**
 * Builds a valid mapbox-gl filter expression our filters, which
 * are organized by key.
 * @example
 * ```
 * getMapboxFilter({foo: {in: ['bar', 'baz']}, qux: {'>=': 1, '<=': 3}})
 * // ['all', ['in', 'foo', bar', 'baz'], ['all', ['>=', 'qux', 1], ['<=', 'qux', 3]]]
 * ```
 * @param {object} filtersByField
 * @return {array} valid mapbox-gl filter
 */
var getMapboxFilter = createSelector(function (state) {
  return state.filters;
}, getFieldAnalysis, function (filters, fieldAnalysis) {
  return Object.keys(filters).reduce(function (p, f) {
    var exp = filters[f];
    if (exp.in) {
      if (isArrayLike(fieldAnalysis[f].type)) {
        var subFilter = ['any', ['in', f].concat(_toConsumableArray(exp.in))];
        for (var i = 0; i < fieldAnalysis[f].maxArrayLength; i++) {
          subFilter.push(['in', f + '.' + i].concat(_toConsumableArray(exp.in)));
        }
        p.push(subFilter);
      } else {
        p.push(['in', f].concat(_toConsumableArray(exp.in)));
      }
    } else if (exp['<='] || exp['>=']) {
      var compoundExp = ['all'];
      if (exp['<=']) compoundExp.push(['<=', f, exp['<=']]);
      if (exp['>=']) compoundExp.push(['>=', f, exp['>=']]);
      p.push(compoundExp);
    }
    return p;
  }, ['all']);
});

module.exports = getMapboxFilter;